@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2022, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -154,6 +150,7 @@ public class CurrencyNames_ne extends OpenListResourceBundle {
             { "MNT", "MNT" },
             { "MOP", "MOP" },
             { "MRO", "MRO" },
+            { "MRU", "MRU" },
             { "MUR", "MUR" },
             { "MVR", "MVR" },
             { "MWK", "MWK" },
@@ -189,6 +186,7 @@ public class CurrencyNames_ne extends OpenListResourceBundle {
             { "SRD", "SRD" },
             { "SSP", "SSP" },
             { "STD", "STD" },
+            { "STN", "STN" },
             { "SYP", "SYP" },
             { "SZL", "SZL" },
             { "THB", "\u0e3f" },
@@ -204,6 +202,7 @@ public class CurrencyNames_ne extends OpenListResourceBundle {
             { "UYU", "UYU" },
             { "UZS", "UZS" },
             { "VEF", "VEF" },
+            { "VES", "VES" },
             { "VUV", "VUV" },
             { "WST", "WST" },
             { "YER", "YER" },
@@ -293,6 +292,7 @@ public class CurrencyNames_ne extends OpenListResourceBundle {
             { "lbp", "\u0932\u0947\u092c\u0928\u093e\u0932\u0940 \u092a\u093e\u0909\u0928\u094d\u0921" },
             { "lkr", "\u0936\u094d\u0930\u0940\u0932\u0919\u094d\u0915\u093e\u0932\u0940 \u0930\u0942\u092a\u093f\u092f\u093e" },
             { "lrd", "\u0932\u093f\u092c\u0947\u0930\u093f\u092f\u093e\u0932\u0940 \u0921\u0932\u0930" },
+            { "lsl", "\u0932\u0947\u0938\u094b\u0925\u094b \u0932\u094b\u091f\u0940" },
             { "ltl", "\u0932\u093f\u0925\u0941\u0928\u093f\u092f\u093e\u0932\u0940 \u0932\u093f\u091f\u093e\u0938" },
             { "lvl", "\u0932\u093e\u091f\u094d\u092d\u093f\u092f\u093e\u0932\u0940 \u0932\u093e\u091f\u094d\u0938" },
             { "lyd", "\u0932\u093f\u0935\u093f\u092f\u093e\u0932\u0940 \u0921\u093f\u0928\u093e\u0930" },
@@ -359,7 +359,8 @@ public class CurrencyNames_ne extends OpenListResourceBundle {
             { "usd", "\u0905\u092e\u0947\u0930\u093f\u0915\u0940 \u0921\u0932\u0930" },
             { "uyu", "\u0909\u0930\u0942\u0917\u0941\u0935\u093e\u092f\u093e\u0932\u0940 \u092a\u0947\u0938\u094b" },
             { "uzs", "\u0909\u091c\u094d\u092c\u0947\u0915\u093f\u0938\u094d\u0924\u093e\u0928 \u0938\u094b\u092e" },
-            { "vef", "\u092d\u0947\u0928\u0947\u091c\u0941\u090f\u0932\u0928 \u092c\u094b\u0932\u093f\u092d\u0930" },
+            { "vef", "\u092d\u0947\u0928\u0947\u091c\u0941\u090f\u0932\u0928 \u092c\u094b\u0932\u093f\u092d\u0930 (\u0968\u0966\u0966\u096e\u2013\u0968\u0966\u0967\u096e)" },
+            { "ves", "\u092d\u0947\u0928\u0947\u091c\u0941\u090f\u0932\u0928 \u092c\u094b\u0932\u093f\u092d\u0930-2" },
             { "vnd", "\u092d\u093f\u092f\u0924\u0928\u093e\u092e\u0940 \u0921\u0919\u094d" },
             { "vuv", "\u092d\u093e\u0928\u0941\u0906\u0924\u0942 \u092d\u093e\u0924\u0941" },
             { "wst", "\u0938\u093e\u092e\u094b\u0906\u0928 \u0924\u093e\u0932\u093e" },
